module PPSVS10MHZ (  	
	input                 RESET_N , 
	input                 CLK_50 , 
	input                 CLK_10M ,
	input                 CLK_PPS ,
	output         [7:0]  ERR_CNT ,
	output  reg    [31:0] CNT ,
	output  reg    [23:0] rRESULT_CNT ,
	output  reg    [23:0] SEC_CNT , 
	output         [23:0] RESULT_CNT ,
	output  reg           READY_, 
	output                READY 
	
);

//=======================================================
//  REG/WIRE declarations
//=======================================================
parameter  REAL_10M  =10000000; 
parameter  REAL_10M2 =REAL_10M*2; 

reg [1:0]  rCLK_PPS  ; 
reg [7:0] rERR_CNT ;

wire TIME_OUT;

//=======================================================
//  Structural coding
//=======================================================
wire HZ ; 
CLOCKMEM ck5( .RESET_N( 1'b1 ) ,.CLK (CLK_50 ) ,. CLK_FREQ ( 400000000 ) , .CK_1HZ (HZ ) ) ; 


TIME_OUR tr( 
  .CLK_50  (CLK_50   ), 
  .RESET_N (RESET_N  ),  
  .SMA_IN  (CLK_10M  ), 
  .SEC     (400000000 ), 
  .TIME_OUT(TIME_OUT ),
) ;


wire   SW ; 
assign SW =   ( (  TIME_OUT ==1      )  ||  (  CNT >=  REAL_10M2 ) ) ?1 :0  ; 

assign RESULT_CNT  = SW? { ERR_CNT ,ERR_CNT ,ERR_CNT  }  : rRESULT_CNT ; 
assign READY       = SW? HZ : READY_ ; 
 


assign ERR_CNT   = 
     (  TIME_OUT ==1      )?0 : ( 
     (  CNT >=  REAL_10M2 )?255 : rERR_CNT
	  ) ; 
	  
	  
always @(negedge RESET_N or posedge  CLK_10M ) 
	if (!RESET_N) begin 
	 rERR_CNT  <=0;
	 CNT       <=0; 
	 rCLK_PPS  <=0; 
	 READY_    <=0; 
	 SEC_CNT   <=0; 
	 
end 
else  begin 
   	 rCLK_PPS  <= { rCLK_PPS[0]  , CLK_PPS }    ; 
		 if ( rCLK_PPS  == 2'b01  )  begin 
		          READY_ <= 1 ;  
		          { rRESULT_CNT[23:0] ,   CNT[23:0] } <= { CNT[23:0],  24'h1 } ; 
					 SEC_CNT<=  SEC_CNT +1 ; 
				  
		        if ( CNT  >= REAL_10M )  begin 
				          rERR_CNT <=  CNT-REAL_10M ; 
				  end 
			     else begin  
				          rERR_CNT <=  REAL_10M - CNT ;   
				  end 
		 end 
		 else  begin 
		         if  ( CNT  <  REAL_10M2  )  CNT<=CNT+1; 
				      READY_ <= 0 ;
		 end 
end


endmodule 
