

module UART_IF(
	input 		          		CK_125,
	output		    [17:0]		LEDR,
	input 		               RESET_N,
	input   [31:0]  PPS_RESULT_CNT ,
	input   [23:0]  SEC_CNT , 
	input           PPS_READY  , 	
	input 		          		UART_RX,
	output		          		UART_TX
);

//=======================================================
//  REG/WIRE declarations
//=======================================================
wire		      DLY_RST;
wire           ADDRESS  ;
wire           CS       ;
wire [3:0]     BYTE_ENABLE     ;
wire           READ     ;
wire           WRITE    ;
wire           IRQ      ;
wire [31:0]    WRITEDATA;
wire [31:0]    READDATA ;
//wire           READY ;
wire           UART_RX_1 ; 
wire [7:0]     MESSAGE;

//=======================================================
//  Structural coding
//=======================================================
// initial // 
assign WIFI_RST_n      = RESET_N   &  DLY_RST ;
	

//---- RESET DELAY  ---	
Reset_Delay	 r0	(	
      .iRESET_N ( RESET_N )  , 
		.iCLK     ( CK_125 ),
		.oRESET   ( DLY_RST  )		
	);
				
//----  FROM ESP8266 RX  ---	
assign UART_RX_1  =  1 ;// ( READY) ? UART_RX :1 ; 

//-- UART DATA SEQUENCE CONTROLLER -- 
UART_ST   st    (	
   .CLK         ( CK_125   ) ,
   .RESET_N     ( DLY_RST & ~PPS_READY  ) ,
  //--pps v.s 10M data
	.PPS_RESULT_CNT  (PPS_RESULT_CNT),	
	.SEC_CNT   ( SEC_CNT) , 
	
   //--UART IP BUS 
   .ADDRESS     ( ADDRESS     ) ,
   .CS          ( CS          ) ,
   .BYTE_ENABLE ( BYTE_ENABLE ),
   .WRITE       ( WRITE     ),
   .WRITEDATA   ( WRITEDATA ),
   .IRQ         ( IRQ       ),
   .READDATA    ( READDATA  ),
	.READY       ( READY     ) ,
	.MESSAGE     ( MESSAGE   )

);

wire  READY  ; 
//--- ALTERA UART IP  --- 
UART  ut  (
	.clk       ( ~CK_125      ) ,
	.reset     ( ~READY      ),
	
	.address   ( ADDRESS     ),
	.chipselect( CS          ),
	.byteenable( BYTE_ENABLE ),
	.read      ( READ        ),
	.write     ( WRITE       ),
	.writedata ( WRITEDATA   ),
	.irq       ( IRQ         ),
	.readdata  ( READDATA    ),	
	
	.UART_RXD  ( UART_RX_1   ),
	.UART_TXD  ( UART_TX     )
);


//---- LED DISPLAY  ---
assign  LEDR[9:0]    = { READY , UART_RX, UART_TX, 3'b00,  MESSAGE[3:0] } ;


endmodule

